@@ -16,6 +16,9 @@ extern SEXP _scModels_cpp_rpb(SEXP, SEXP, SEXP, SEXP);
 extern SEXP _scModels_cpp_gmRNA_switch(SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP _scModels_cpp_gmRNA_burst(SEXP, SEXP, SEXP, SEXP);
 extern SEXP _scModels_cpp_gmRNA_basic(SEXP, SEXP, SEXP);
+extern SEXP _scModels_cpp_gmRNA_basic_burst(SEXP, SEXP, SEXP, SEXP, SEXP);
+extern SEXP _scModels_cpp_rInvGaus(SEXP, SEXP, SEXP);
+
 
 static const R_CallMethodDef CallEntries[] = {
   {"_scModels_chf_1F1", (DL_FUNC) &_scModels_chf_1F1, 3},
@@ -26,6 +29,8 @@ static const R_CallMethodDef CallEntries[] = {
   {"_scModels_cpp_gmRNA_switch",       (DL_FUNC) &_scModels_cpp_gmRNA_switch,       5},
   {"_scModels_cpp_gmRNA_burst",       (DL_FUNC) &_scModels_cpp_gmRNA_burst,       4},
   {"_scModels_cpp_gmRNA_basic",       (DL_FUNC) &_scModels_cpp_gmRNA_basic,       3},
+  {"_scModels_cpp_gmRNA_basic_burst",       (DL_FUNC) &_scModels_cpp_gmRNA_basic_burst,       5},
+  {"_scModels_cpp_rInvGaus",    (DL_FUNC) &_scModels_cpp_rInvGaus,    3},
   {NULL, NULL, 0}
 };
 
